# Twitter-Korean-Text (Open-Korean-Text) 의 resources 

현재 디렉토리에 있는 파일들은 구 [트위터한국어분석기][twitterlink] (현 [오픈한국어트위터분석기][openlink])의 언어자원 입니다. 

The files in this directory are language resource such as noun or josa dictionary that used in Twitter-Korean-Text (Open-Korean-Text). 



[twitterlink]: https://github.com/twitter/twitter-korean-text
[openlink]: https://github.com/open-korean-text/open-korean-text